"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.askQuestions = exports.defaultGetAnswersFromPrompt = void 0;
const questions_1 = require("../../../common/questions");
const refineAnswers_1 = require("./pieces/refineAnswers");
const utils_1 = require("../../../common/utils");
/**
 * Simply asks the given questions. Usable in most cases (when you don't need complex logic
 * e.g. determine whether to ask a question based on an answer to another question).
 *
 * @param projectModel
 * @param gen
 * @param options
 * @param questions
 */
const defaultGetAnswersFromPrompt = (projectModel, gen, options, questions) => __awaiter(void 0, void 0, void 0, function* () {
    if (questions == null) {
        utils_1.throwError(gen, 'Questions not provided');
    }
    const answers = yield exports.askQuestions(questions, projectModel, gen);
    options.verbose && gen.log('Component config:\n' + JSON.stringify(answers));
    return answers;
});
exports.defaultGetAnswersFromPrompt = defaultGetAnswersFromPrompt;
/**
 * Asks the given questions and returns *refined* answers.
 *
 * @param questions
 * @param projectModel
 * @param gen
 */
const askQuestions = (questions, projectModel, gen) => __awaiter(void 0, void 0, void 0, function* () {
    const rawAnswers = yield gen.prompt(questions_1.fromStudioProperties(questions, projectModel));
    return refineAnswers_1.refineAnswers(projectModel, questions, rawAnswers);
});
exports.askQuestions = askQuestions;
//# sourceMappingURL=defaultGetAnswersFromPrompt.js.map