"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deriveEditorTemplateModel = void 0;
const relations_1 = require("./relations");
/**
 * Derives template model that is common for editors (does not include edit attributes as there are multiple ways
 * of obtaining them depending on whether we use REST or GraphQL).
 *
 * @param answers
 * @param projectModel
 * @param editAttributes
 * @param entityWithPath
 */
function deriveEditorTemplateModel(answers, projectModel, editAttributes) {
    const readOnlyFields = editAttributes
        .filter((attr) => attr.readOnly)
        .map((attr) => attr.name);
    const { associations, compositions } = relations_1.getRelations(projectModel, editAttributes);
    const nestedEntityInfo = answers.nestedEntityInfo;
    const relationImports = relations_1.getRelationImports(associations, answers.entity);
    const associatedEntityClassNames = Array.from(new Set(Object.values(associations)
        .map(entity => entity.className)));
    return {
        readOnlyFields,
        associations,
        compositions,
        nestedEntityInfo,
        relationImports,
        associatedEntityClassNames,
    };
}
exports.deriveEditorTemplateModel = deriveEditorTemplateModel;
//# sourceMappingURL=editor.js.map