"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deriveStringIdAnswers = void 0;
const entity_1 = require("../../../../../generators/react-typescript/common/entity");
const cuba_model_utils_1 = require("../../../../../common/model/cuba-model-utils");
// Moved (almost) unchanged from src/common
function deriveStringIdAnswers(answers, projectModel, listAttributesArg, editAttributesArg) {
    var _a;
    const listAttributes = listAttributesArg.slice();
    const editAttributes = editAttributesArg === null || editAttributesArg === void 0 ? void 0 : editAttributesArg.slice();
    if (!entity_1.isStringIdEntity(projectModel, answers.entity)) {
        return {
            listAttributes,
            editAttributes: editAttributes
        };
    }
    const stringIdName = (_a = answers.entity.idAttributeName) !== null && _a !== void 0 ? _a : answers.idAttrName;
    if (stringIdName == null) {
        throw new Error('Could not find the stringIdName');
    }
    const allEntityAttributes = cuba_model_utils_1.collectAttributesFromHierarchy(answers.entity, projectModel);
    const idAttr = allEntityAttributes.find(attr => attr.name === stringIdName);
    if (idAttr == null) {
        throw new Error(`Unable to find ID attribute. Expected the ID attribute to be named "${stringIdName}".`);
    }
    if (editAttributes != null && stringIdName !== 'id') {
        const impostorAttrIndex = editAttributes.findIndex(attr => attr.name === 'id');
        if (impostorAttrIndex !== -1) {
            // An edge case when we have a non-ID string attribute named "id", and a differently named ID attribute.
            // We do not show the attribute named "id" in the editor.
            // We still show it in the List Component (it will display the same value as the real ID attribute).
            editAttributes.splice(impostorAttrIndex, 1);
        }
    }
    if (editAttributes != null && answers.editIdAttrPos != null) {
        editAttributes.splice(answers.editIdAttrPos, 0, idAttr);
    }
    if (answers.listShowIdAttr && answers.listIdAttrPos != null) {
        listAttributes.splice(answers.listIdAttrPos, 0, idAttr);
    }
    return {
        stringIdName,
        listAttributes,
        editAttributes: editAttributes
    };
}
exports.deriveStringIdAnswers = deriveStringIdAnswers;
//# sourceMappingURL=string-id.js.map