"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTopAttributesFromQuery = void 0;
const graphql_tag_1 = __importDefault(require("graphql-tag"));
/**
 * Parses the provided GraphQL query string and returns an array of top-level attributes.
 *
 * @param query
 */
function getTopAttributesFromQuery(query) {
    const documentNode = graphql_tag_1.default(query);
    if (!('selectionSet' in documentNode.definitions[0])) {
        throw new Error(`DocumentNode built from provided query string does not contain selectionSet. DocumentNode: ${JSON.stringify(documentNode)}`);
    }
    return documentNode
        .definitions[0]
        .selectionSet
        .selections
        .filter((node) => 'name' in node)
        .map((node) => {
        if ('name' in node) {
            return node.name.value;
        }
        // Should be unreachable due to .filter, this code is to avoid compilation error
        throw new Error(`Cannot find name in SelectionNode. DocumentNode: ${JSON.stringify(documentNode)}`);
    });
}
exports.getTopAttributesFromQuery = getTopAttributesFromQuery;
//# sourceMappingURL=getTopAttributesFromQuery.js.map