"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.transformAddScreenItem = exports.transformAddScreenImport = exports.addMvpAppMenu = void 0;
const path_1 = __importDefault(require("path"));
const jscodeshift_1 = __importStar(require("jscodeshift"));
const utils_1 = require("../../../../../common/utils");
const j = jscodeshift_1.default;
function addMvpAppMenu({ gen, dirShift, route, componentName, pathToComponent }) {
    const destRoot = gen.destinationRoot();
    const srcDir = path_1.default.join(destRoot, dirShift ? dirShift : '');
    const componentPath = pathToComponent !== null && pathToComponent !== void 0 ? pathToComponent : `./${getRelativePath(path_1.default.join(srcDir, 'app'), destRoot)}/${componentName}`;
    const appMenuPath = path_1.default.join(srcDir, 'app', 'AppMenu.tsx');
    if (!gen.fs.exists(appMenuPath)) {
        gen.log('Unable to add component to menu: app menu not found');
        return;
    }
    const appMenuContents = gen.fs.read(appMenuPath);
    const appMenuTransformed = transformAddMenuItem(appMenuContents, route);
    gen.fs.write(appMenuPath, appMenuTransformed);
    const screenRegistryFilePath = path_1.default.join(srcDir, 'app', 'screenRegistry.ts');
    if (!gen.fs.exists(screenRegistryFilePath)) {
        gen.log('Unable to add component to menu: screen registry not found');
        return;
    }
    const screenRegistryFileContent = gen.fs.read(screenRegistryFilePath);
    let screenRegistryTransformed;
    screenRegistryTransformed = transformAddScreenItem(screenRegistryFileContent, route, componentName);
    screenRegistryTransformed = transformAddScreenImport(screenRegistryTransformed, componentName, componentPath);
    gen.fs.write(screenRegistryFilePath, screenRegistryTransformed);
}
exports.addMvpAppMenu = addMvpAppMenu;
function transformAddMenuItem(source, route) {
    const menuItemJSX = createMenuItemJSX(route);
    const tsxParser = j.withParser('tsx');
    const appMenuAST = tsxParser(source);
    const addonsMenu = appMenuAST.findJSXElements("AddonsMenu");
    if (addonsMenu.length) {
        addonsMenu.insertBefore(jscodeshift_1.stringLiteral(menuItemJSX));
        return addonsMenu.toSource();
    }
    const menu = appMenuAST.findJSXElements('Menu');
    const [{ value: { children } }] = menu.paths();
    children === null || children === void 0 ? void 0 : children.push(jscodeshift_1.stringLiteral(menuItemJSX));
    return appMenuAST.toSource();
}
function transformAddScreenImport(source, componentName, componentPath, isDefault = false) {
    const tsxParser = j.withParser('tsx');
    const ast = tsxParser(source);
    const existingSpecifiers = ast.find(j.ImportDeclaration)
        .find(j.ImportSpecifier)
        .filter(path => path.node.imported.name === componentName);
    const alreadyImported = existingSpecifiers.length > 0;
    if (alreadyImported) {
        return source;
    }
    const importSpecifier = isDefault ? j.importDefaultSpecifier : j.importSpecifier;
    const newImport = j.importDeclaration([importSpecifier(j.identifier(componentName))], j.stringLiteral(componentPath));
    ast.get().node.program.body.unshift(newImport);
    return ast.toSource();
}
exports.transformAddScreenImport = transformAddScreenImport;
function transformAddScreenItem(
// eslint-disable-next-line @typescript-eslint/no-unused-vars
source, route, componentName) {
    const tsParser = j.withParser('ts');
    const screenRegistryAST = tsParser(source);
    const content = screenRegistryAST.toSource();
    const registerScreen = `
    screenStore.registerScreen('${route}', {
      component: ${componentName},
      captionKey: 'screen.${componentName}'   
    });
  `;
    const updatedContent = `
    ${content} 
    ${registerScreen}
  `;
    return updatedContent;
}
exports.transformAddScreenItem = transformAddScreenItem;
function createMenuItemJSX(key) {
    return `
    <Menu.Item
      title={getCaption('${key}')}
      key='${key}'
    >
      {getCaption('${key}')}
    </Menu.Item>
  `;
}
function getRelativePath(routingDir, destRoot) {
    return utils_1.convertToUnixPath(path_1.default.relative(routingDir, destRoot));
}
//# sourceMappingURL=addMvpAppMenu.js.map