"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getUpdatedMenuWithCustomNode = exports.getUpdatedMenuWithRootNode = exports.pushStringNodeToParentChildren = exports.getNewMenuItem = exports.updateAppMenuContent = exports.addAppMenuItem = exports.addRoute = exports.addToAppMenu = exports.addToMenu = void 0;
const path_1 = __importDefault(require("path"));
const uuid_1 = __importDefault(require("uuid"));
const utils_1 = require("../../../common/utils");
const jscodeshift_1 = __importStar(require("jscodeshift"));
function addToMenu(fs, { destRoot, dirShift, caption, menuLink, pathPattern, componentFileName, componentClassName }, addRouteCallback = exports.addRoute, customComponentParams) {
    const routingDir = path_1.default.join(destRoot, dirShift ? dirShift : '');
    const routingPath = path_1.default.join(routingDir, 'routing.ts');
    const componentPath = `./${getRelativePath(routingDir, destRoot)}/${componentFileName}`;
    if (fs.exists(routingPath)) {
        const routingContents = fs.read(routingPath);
        fs.write(routingPath, addRouteCallback(routingContents, { caption, menuLink, pathPattern, componentClassName, componentFileName, componentPath }, customComponentParams));
        return true;
    }
    else {
        return false;
    }
}
exports.addToMenu = addToMenu;
function addToAppMenu(fs, { destRoot, dirShift, menuNode, componentClassName }, addAppMenuCallback = exports.addAppMenuItem, customComponentParams) {
    const appMenuDir = path_1.default.join(destRoot, dirShift ? dirShift : '');
    const appMenuPath = path_1.default.join(appMenuDir, 'app', 'AppMenu.tsx');
    if (fs.exists(appMenuPath)) {
        const appMenuContents = fs.read(appMenuPath);
        fs.write(appMenuPath, addAppMenuCallback(appMenuContents, { componentClassName, menuNode }, customComponentParams));
        return true;
    }
    else {
        return false;
    }
}
exports.addToAppMenu = addToAppMenu;
const addRoute = (routingContents, { 
// eslint-disable-next-line @typescript-eslint/no-unused-vars
caption, pathPattern, menuLink, componentClassName, componentPath }) => `` +
    `import '${componentPath}';
${routingContents}`;
exports.addRoute = addRoute;
const addAppMenuItem = (appMenuContents, { componentClassName, menuNode }) => {
    return updateAppMenuContent(appMenuContents, componentClassName, menuNode, uuid_1.default.v4());
};
exports.addAppMenuItem = addAppMenuItem;
function getUpdatedAppMenuContent(appMenuContents, menuNode, componentClassName, key) {
    const tsxParser = jscodeshift_1.default.withParser('tsx');
    const appMenuAST = tsxParser(appMenuContents);
    const newMenuItem = getNewMenuItem(componentClassName, key);
    if (menuNode === "ROOT") {
        return getUpdatedMenuWithRootNode(appMenuAST, newMenuItem);
    }
    return getUpdatedMenuWithCustomNode(appMenuAST, menuNode, newMenuItem);
}
function updateAppMenuContent(appMenuContents, componentClassName, menuNode, key) {
    return menuNode
        ? getUpdatedAppMenuContent(appMenuContents, menuNode, componentClassName, key)
        : appMenuContents;
}
exports.updateAppMenuContent = updateAppMenuContent;
function getNewMenuItem(componentClassName, key) {
    return `
    <MenuItem 
      screenId={"${componentClassName}"}
      icon={<BarsOutlined />}
      caption={"screen.${componentClassName}"}
      key={'${key}'}
    />`;
}
exports.getNewMenuItem = getNewMenuItem;
function pushStringNodeToParentChildren(parrent, stringNode) {
    const parrentPaths = parrent.paths();
    if (parrentPaths.length) {
        const [{ value: { children } }] = parrentPaths;
        children === null || children === void 0 ? void 0 : children.push(jscodeshift_1.stringLiteral(stringNode));
        return parrent.toSource();
    }
    return parrent.toSource();
}
exports.pushStringNodeToParentChildren = pushStringNodeToParentChildren;
function getUpdatedMenuWithRootNode(appMenuAST, newMenuItem) {
    const verticalMenu = appMenuAST.findJSXElements('VerticalMenu');
    if (verticalMenu.length) {
        return pushStringNodeToParentChildren(verticalMenu, newMenuItem);
    }
    const horizontalMenu = appMenuAST.findJSXElements('HorizontalMenu');
    if (horizontalMenu.length) {
        return pushStringNodeToParentChildren(horizontalMenu, newMenuItem);
    }
    return appMenuAST.toSource();
}
exports.getUpdatedMenuWithRootNode = getUpdatedMenuWithRootNode;
function getUpdatedMenuWithCustomNode(appMenuAST, menuNode, newMenuItem) {
    const parrentSubMenuItem = appMenuAST
        .findJSXElements("SubMenuItem")
        .find(jscodeshift_1.JSXAttribute, {
        name: {
            type: "JSXIdentifier",
            name: "key"
        },
        value: {
            type: "JSXExpressionContainer",
            expression: {
                type: 'StringLiteral',
                value: menuNode
            }
        }
    })
        .closest(jscodeshift_1.JSXElement);
    return pushStringNodeToParentChildren(parrentSubMenuItem, newMenuItem);
}
exports.getUpdatedMenuWithCustomNode = getUpdatedMenuWithCustomNode;
function getRelativePath(routingDir, destRoot) {
    return utils_1.convertToUnixPath(path_1.default.relative(routingDir, destRoot));
}
//# sourceMappingURL=menu.js.map