"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const i18n_1 = require("../../../../generators/react-typescript/common/i18n");
const chai_1 = require("chai");
const sinon_1 = __importDefault(require("sinon"));
const sinon_chai_1 = __importDefault(require("sinon-chai"));
chai_1.use(sinon_chai_1.default);
const expectEnPath = 'directory/shift/i18n/en.json';
const expectRuPath = 'directory/shift/i18n/ru.json';
const enExisting = {
    'key1': 'predefined value 1',
    'key3': 'predefined value 3',
    'keyNotInTemplate': 'key not in template'
};
const ruExisting = {
    'key1': 'заранее заданное значение 1',
    'key3': 'заранее заданное значение 3',
    'key4': 'заранее заданное значение 4',
    'keyNotInTemplate': 'ключ, отсутствующий в шаблоне'
};
let fs;
let writeJSON;
describe('i18n generation', () => {
    beforeEach(() => {
        writeJSON = sinon_1.default.fake();
        fs = { writeJSON };
    });
    it('should write i18n messages when message files are empty', () => {
        const readJSON = sinon_1.default.stub();
        fs.readJSON = readJSON;
        readJSON.returns(null);
        i18n_1.writeComponentI18nMessages(fs, "componentClassName", './directory/shift');
        chai_1.expect(readJSON).calledWith(expectRuPath);
        chai_1.expect(readJSON).calledWith(expectEnPath);
        chai_1.expect(writeJSON).not.calledWith(expectRuPath);
        chai_1.expect(writeJSON).calledWith(expectEnPath, { 'screen.componentClassName': 'Component Class Name' });
        readJSON.returns({});
        i18n_1.writeComponentI18nMessages(fs, "componentClassName", './directory/shift');
        chai_1.expect(readJSON).calledWith(expectRuPath);
        chai_1.expect(readJSON).calledWith(expectEnPath);
        chai_1.expect(writeJSON).not.calledWith(expectRuPath);
        chai_1.expect(writeJSON).calledWith(expectEnPath, { 'screen.componentClassName': 'Component Class Name' });
    });
    it('should merge and write i18n messages', () => {
        const enTemplate = {
            'key1': 'template value 1',
            'key2': 'template value 2',
            'key3': 'template value 3',
            'key4': 'template value 4',
            'key5': 'template value 5',
        };
        const ruTemplate = {
            'key1': 'значение из шаблона 1',
            'key2': 'значение из шаблона 2',
            'key3': 'значение из шаблона 3',
            'key4': 'значение из шаблона 4',
            'key5': 'значение из шаблона 5',
        };
        const enExpected = {
            'key1': 'predefined value 1',
            'key2': 'template value 2',
            'key3': 'predefined value 3',
            'key4': 'template value 4',
            'key5': 'template value 5',
            'screen.testClass': 'Test Class',
            'keyNotInTemplate': 'key not in template'
        };
        const ruExpected = {
            'key1': 'заранее заданное значение 1',
            'key2': 'значение из шаблона 2',
            'key3': 'заранее заданное значение 3',
            'key4': 'заранее заданное значение 4',
            'key5': 'значение из шаблона 5',
            'keyNotInTemplate': 'ключ, отсутствующий в шаблоне'
        };
        const readJSON = sinon_1.default.stub();
        readJSON.withArgs(expectEnPath).returns(enExisting);
        readJSON.withArgs(expectRuPath).returns(ruExisting);
        fs.readJSON = readJSON;
        i18n_1.writeComponentI18nMessages(fs, 'testClass', './directory/shift', undefined, {
            en: enTemplate,
            ru: ruTemplate
        });
        chai_1.expect(writeJSON).calledWith(expectEnPath, enExpected);
        chai_1.expect(writeJSON).calledWith(expectRuPath, ruExpected);
    });
    it('should not call write method, if no rows are added', () => {
        const readJSON = sinon_1.default.stub();
        fs.readJSON = readJSON;
        readJSON.withArgs(expectRuPath).returns(ruExisting);
        // case where all keys, include 'router.*' already exist in file and have the same values
        readJSON.withArgs(expectEnPath).returns(Object.assign({ 'screen.testClass': 'Test Class' }, enExisting));
        i18n_1.writeComponentI18nMessages(fs, 'testClass', './directory/shift');
        chai_1.expect(writeJSON).not.calledWith(expectRuPath);
        chai_1.expect(writeJSON).not.calledWith(expectEnPath);
        let enJson = { 'key1': 'predefined value 1' };
        i18n_1.writeComponentI18nMessages(fs, 'testClass', './directory/shift', undefined, { en: enJson });
        chai_1.expect(writeJSON).not.calledWith(expectRuPath);
        chai_1.expect(writeJSON).not.calledWith(expectEnPath);
        i18n_1.writeComponentI18nMessages(fs, 'testClass', './directory/shift', undefined, {
            en: enExisting,
            ru: ruExisting
        });
        chai_1.expect(writeJSON).not.calledWith(expectRuPath);
        chai_1.expect(writeJSON).not.calledWith(expectEnPath);
        readJSON.withArgs(expectEnPath).returns(Object.assign({ 'screen.testClass': 'Test Class' }, enExisting));
        enJson = { 'key1': 'new value 1' };
        i18n_1.writeComponentI18nMessages(fs, 'testClass', './directory/shift', undefined, { en: enJson });
        chai_1.expect(writeJSON).not.calledWith(expectRuPath);
        chai_1.expect(writeJSON).not.calledWith(expectRuPath);
    });
});
describe('i18n generation - project locales', () => {
    const messages = {
        en: { 'key0': 'new value 0' },
        ru: { 'key0': 'новое значение 0' }
    };
    const enLocale = { code: 'en', caption: 'English' };
    const ruLocale = { code: 'ru', caption: 'Русский' };
    const projectLocalesEnRu = [enLocale, ruLocale];
    const projectLocalesEn = [enLocale];
    const projectLocalesRu = [ruLocale];
    beforeEach(() => {
        writeJSON = sinon_1.default.fake();
        fs = { writeJSON };
        const readJSON = sinon_1.default.stub();
        readJSON.withArgs(expectEnPath).returns(enExisting);
        readJSON.withArgs(expectRuPath).returns(ruExisting);
        fs.readJSON = readJSON;
    });
    it('should write en and ru messages if the project contains both locales', () => {
        i18n_1.writeComponentI18nMessages(fs, 'testClass', './directory/shift', projectLocalesEnRu, messages);
        chai_1.expect(writeJSON).calledWith(expectEnPath);
        chai_1.expect(writeJSON).calledWith(expectRuPath);
    });
    it('should only write en messages if the project only contains en locale', () => {
        i18n_1.writeComponentI18nMessages(fs, 'testClass', './directory/shift', projectLocalesEn, messages);
        chai_1.expect(writeJSON).calledWith(expectEnPath);
        chai_1.expect(writeJSON).not.calledWith(expectRuPath);
    });
    it('should only write ru messages if the project only contains ru locale', () => {
        i18n_1.writeComponentI18nMessages(fs, 'testClass', './directory/shift', projectLocalesRu, messages);
        chai_1.expect(writeJSON).not.calledWith(expectEnPath);
        chai_1.expect(writeJSON).calledWith(expectRuPath);
    });
    it('should write both en and ru messages if the project locales are unknown', () => {
        i18n_1.writeComponentI18nMessages(fs, 'testClass', './directory/shift', undefined, messages);
        chai_1.expect(writeJSON).calledWith(expectEnPath);
        chai_1.expect(writeJSON).calledWith(expectRuPath);
    });
});
// TODO
describe('i18n message packs', () => __awaiter(void 0, void 0, void 0, function* () {
    xit('has the same keys', () => __awaiter(void 0, void 0, void 0, function* () {
        for (const locale of i18n_1.SUPPORTED_CLIENT_LOCALES) {
            const appMessagePack = yield Promise.resolve().then(() => __importStar(require(`../../../../generators/react-typescript/app/template/i18n-message-packs/${locale.name}.json`)));
            const entityBrowserMessagePack = yield Promise.resolve().then(() => __importStar(require(`../../../../generators/react-typescript/entity-browser/template/browser-i18n-messages/${locale.name}.json`)));
            const entityEditorMessagePack = yield Promise.resolve().then(() => __importStar(require(`../../../../generators/react-typescript/entity-editor/template/editor-i18n-messages/${locale.name}.json`)));
            const masterDetailMessagePack = yield Promise.resolve().then(() => __importStar(require(`../../../../generators/react-typescript/entity-master-detail/template/master-detail-i18n-messages/${locale.name}.json`)));
            const mergedMessagePack = Object.assign(Object.assign(Object.assign(Object.assign({}, appMessagePack), entityBrowserMessagePack), entityEditorMessagePack), masterDetailMessagePack);
            const actualKeys = Object.keys(mergedMessagePack);
            chai_1.expect(actualKeys.sort()).to.deep.equal(EXPECTED_I18N_KEYS.sort());
        }
    }));
}));
const EXPECTED_I18N_KEYS = [
    // Main message pack
    "common.ok",
    "common.cancel",
    "common.create",
    "common.edit",
    "common.remove",
    "common.submit",
    "common.next",
    "common.previous",
    "common.unsavedEntity",
    "common.requestFailed",
    "common.retry",
    "common.back",
    "default",
    "editor.doesNotExist",
    "home.welcome",
    "screen.home",
    "login.failed",
    "login.placeholder.login",
    "login.placeholder.password",
    "login.loginBtn",
    "header.logout.areYouSure",
    "header.logout.ok",
    "header.logout.cancel",
    "file.download.notAllowed",
    "file.noFile",
    "jmix.dataTable.clearAllFilters",
    "jmix.dataTable.validation.requiredField",
    "jmix.dataTable.validation.uuid",
    "jmix.dataTable.failedToLoadNestedEntities",
    "jmix.dataTable.loading",
    "jmix.dataTable.operator.__inInterval",
    "jmix.dataTable.operator._contains",
    "jmix.dataTable.operator._doesNotContain",
    "jmix.dataTable.operator._endsWith",
    "jmix.dataTable.operator._in",
    "jmix.dataTable.operator._isNull",
    "jmix.dataTable.operator._notIn",
    "jmix.dataTable.operator._startsWith",
    "jmix.dataTable.yes",
    "jmix.dataTable.no",
    "jmix.dataTable.ok",
    "jmix.dataTable.reset",
    "jmix.dataTable.add",
    "jmix.dataTable.intervalEditor.last",
    "jmix.dataTable.intervalEditor.next",
    "jmix.dataTable.intervalEditor.predefined",
    "jmix.dataTable.intervalEditor.today",
    "jmix.dataTable.intervalEditor.yesterday",
    "jmix.dataTable.intervalEditor.tomorrow",
    "jmix.dataTable.intervalEditor.lastMonth",
    "jmix.dataTable.intervalEditor.thisMonth",
    "jmix.dataTable.intervalEditor.nextMonth",
    "jmix.dataTable.intervalEditor.days",
    "jmix.dataTable.intervalEditor.hours",
    "jmix.dataTable.intervalEditor.minutes",
    "jmix.dataTable.intervalEditor.months",
    "jmix.dataTable.intervalEditor.includingCurrent",
    "jmix.dataTable.listEditor.addItem",
    "jmix.file.downloading",
    "jmix.file.downloadFailed",
    "jmix.fileUpload.replace",
    "jmix.fileUpload.upload",
    "jmix.fileUpload.uploadFailed",
    "jmix.form.validation.childError",
    "jmix.imagePreview.title",
    "jmix.imagePreview.alt",
    "jmix.imagePreview.close",
    "jmix.imagePreview.download",
    "jmix.nestedEntityField.create",
    "jmix.nestedEntityField.delete.areYouSure",
    "jmix.nestedEntitiesTableField.delete.areYouSure",
    "jmix.nestedEntityField.addEntities",
    "jmix.nestedEntityField.andXMore",
    "list.doesNotExist",
    "cubaRest.error.serverNotResponded",
    "cubaRest.error.serverError",
    "cubaRest.error.badRequest",
    "cubaRest.error.unauthorized",
    "cubaRest.error.notFound",
    "cubaRest.error.unknown",
    "antd.form.validation.default",
    "antd.form.validation.required",
    "antd.form.validation.enum",
    "antd.form.validation.whitespace",
    "antd.form.validation.date.format",
    "antd.form.validation.date.parse",
    "antd.form.validation.date.invalid",
    "antd.form.validation.types.string",
    "antd.form.validation.types.method",
    "antd.form.validation.types.array",
    "antd.form.validation.types.object",
    "antd.form.validation.types.number",
    "antd.form.validation.types.date",
    "antd.form.validation.types.boolean",
    "antd.form.validation.types.integer",
    "antd.form.validation.types.float",
    "antd.form.validation.types.regexp",
    "antd.form.validation.types.email",
    "antd.form.validation.types.url",
    "antd.form.validation.types.hex",
    "antd.form.validation.string.len",
    "antd.form.validation.string.min",
    "antd.form.validation.string.max",
    "antd.form.validation.string.range",
    "antd.form.validation.number.len",
    "antd.form.validation.number.min",
    "antd.form.validation.number.max",
    "antd.form.validation.number.range",
    "antd.form.validation.array.len",
    "antd.form.validation.array.min",
    "antd.form.validation.array.max",
    "antd.form.validation.array.range",
    "antd.form.validation.pattern.mismatch",
    // Entity management
    "management.browser.delete.areYouSure",
    "management.browser.delete.ok",
    "management.browser.noItems",
    "management.editor.validationError",
    "management.editor.created",
    "management.editor.updated",
    "masterDetail.create.ifEntitySelected",
    "masterDetail.entityUnselected",
];
//# sourceMappingURL=i18n.test.js.map